@@ -28,17 +28,18 @@
 class DecoderFFapFactory : public QObject, DecoderFactory
 {
     Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.qmmp.qmmp.DecoderFactoryInterface.1.0")
     Q_INTERFACES(DecoderFactory)
 
 public:
-    bool canDecode(QIODevice *input) const;
-    DecoderProperties properties() const;
-    Decoder *create(const QString &url, QIODevice *i);
-    QList<TrackInfo *> createPlayList(const QString &path, TrackInfo::Parts parts, QStringList *);
-    MetaDataModel* createMetaDataModel(const QString &path, bool readOnly);
-    void showSettings(QWidget *parent);
-    void showAbout(QWidget *parent);
-    QString translation() const;
+    bool canDecode(QIODevice *input) const override;
+    DecoderProperties properties() const override;
+    Decoder *create(const QString &url, QIODevice *i) override;
+    QList<TrackInfo *> createPlayList(const QString &path, TrackInfo::Parts parts, QStringList *) override;
+    MetaDataModel* createMetaDataModel(const QString &path, bool readOnly) override;
+    void showSettings(QWidget *parent) override;
+    void showAbout(QWidget *parent) override;
+    QString translation() const override;
 };
 
 #endif
