@@ -514,12 +514,12 @@ ape_read_header (FFap_decoder *decoder)
         else
             ape->bps = 16;
 
-        if (ape->fileversion >= 3950)
+        //if (ape->fileversion >= 3950)
             ape->blocksperframe = 73728 * 4;
-        else if (ape->fileversion >= 3900 || (ape->fileversion >= 3800  && ape->compressiontype >= 4000))
+        /*else if (ape->fileversion >= 3900 || (ape->fileversion >= 3800  && ape->compressiontype >= 4000))
             ape->blocksperframe = 73728;
         else
-            ape->blocksperframe = 9216;
+            ape->blocksperframe = 9216;*/
 
         /* Skip any stored wav header */
         if (!(ape->formatflags & MAC_FORMAT_FLAG_CREATE_WAV_HEADER)) {
@@ -726,7 +726,7 @@ int ffap_init(FFap_decoder *decoder)
     decoder->bps = decoder->ape_ctx->bps;
     decoder->samplerate = decoder->ape_ctx->samplerate;
     decoder->channels = decoder->ape_ctx->channels;
-    decoder->duration = decoder->ape_ctx->totalsamples / decoder->samplerate;
+    decoder->duration = (float)decoder->ape_ctx->totalsamples / decoder->samplerate;
     decoder->readpos = 0;
 
 
@@ -1574,7 +1574,7 @@ ape_decode_frame(FFap_decoder *decoder, void *data, int *data_size)
     int skip = min (s->samplestoskip, blockstodecode);
     i = skip;
 
-    if (decoder->bps == 32) {
+    if (decoder->bps == 32 || decoder->bps == 24) {
         for (; i < blockstodecode; i++) {
             *((int32_t*)samples) = s->decoded0[i];
             samples += 4;
@@ -1584,24 +1584,6 @@ ape_decode_frame(FFap_decoder *decoder, void *data, int *data_size)
             }
         }
     }
-    else if (decoder->bps == 24) {
-        for (; i < blockstodecode; i++) {
-            int32_t sample = s->decoded0[i];
-            samples[0] = sample&0xff;
-            samples[1] = (sample&0xff00)>>8;
-            samples[2] = (sample&0xff0000)>>16;
-            samples[3] = 0;
-            samples += 4;
-            if(s->channels > 1) {
-                sample = s->decoded1[i];
-                samples[0] = sample&0xff;
-                samples[1] = (sample&0xff00)>>8;
-                samples[2] = (sample&0xff0000)>>16;
-                samples[3] = 0;
-                samples += 4;
-            }
-        }
-    }
     else if (decoder->bps == 16) {
         for (; i < blockstodecode; i++) {
             *((int16_t*)samples) = (int16_t)s->decoded0[i];
@@ -1642,7 +1624,7 @@ error:
     return bytes_used;
 }
 
-int ffap_read(FFap_decoder *decoder, char *buffer, int size)
+int ffap_read(FFap_decoder *decoder, unsigned char *buffer, int size)
 {
     int samplesize = decoder->bps / 8 * decoder->channels;
     if(decoder->bps == 24)
