@@ -4,37 +4,37 @@
 <context>
     <name>DecoderFFapFactory</name>
     <message>
-        <location filename="../decoderffapfactory.cpp" line="46"/>
+        <location filename="../decoderffapfactory.cpp" line="43"/>
         <source>FFap Plugin</source>
-        <translation>Greffon FFap</translation>
+        <translation>Plugin FFap</translation>
     </message>
     <message>
-        <location filename="../decoderffapfactory.cpp" line="48"/>
+        <location filename="../decoderffapfactory.cpp" line="45"/>
         <source>Monkey&apos;s Audio Files</source>
         <translation>Fichiers audio Monkey</translation>
     </message>
     <message>
-        <location filename="../decoderffapfactory.cpp" line="168"/>
+        <location filename="../decoderffapfactory.cpp" line="157"/>
         <source>About FFap Audio Plugin</source>
-        <translation>A propos du greffon audio FFap</translation>
+        <translation>A propos du plugin audio FFap</translation>
     </message>
     <message>
-        <location filename="../decoderffapfactory.cpp" line="169"/>
+        <location filename="../decoderffapfactory.cpp" line="158"/>
         <source>Qmmp FFap Audio Plugin</source>
-        <translation>Greffon audio FFap Qmmp</translation>
+        <translation>Plugin audio FFap Qmmp</translation>
     </message>
     <message>
-        <location filename="../decoderffapfactory.cpp" line="170"/>
+        <location filename="../decoderffapfactory.cpp" line="159"/>
         <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
-        <translation>Ce greffon fournit le support des fichiers audio Monkey (APE)</translation>
+        <translation>Ce plugin fournit le support des fichiers audio Monkey (APE)</translation>
     </message>
     <message>
-        <location filename="../decoderffapfactory.cpp" line="171"/>
+        <location filename="../decoderffapfactory.cpp" line="160"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decoderffapfactory.cpp" line="172"/>
+        <location filename="../decoderffapfactory.cpp" line="161"/>
         <source>Based on code from deadbeef, FFmpeg and rockbox</source>
         <translation>Basé sur le code de deadbeef, FFmpeg et rockbox</translation>
     </message>
@@ -42,12 +42,12 @@
 <context>
     <name>FFapMetaDataModel</name>
     <message>
-        <location filename="../ffapmetadatamodel.cpp" line="80"/>
+        <location filename="../ffapmetadatamodel.cpp" line="67"/>
         <source>Samples</source>
         <translation>Samples</translation>
     </message>
     <message>
-        <location filename="../ffapmetadatamodel.cpp" line="82"/>
+        <location filename="../ffapmetadatamodel.cpp" line="68"/>
         <source>Version</source>
         <translation>Version</translation>
     </message>
